@@ -1666,7 +1666,7 @@ yyreduce:
 		cur_fa->selected_protos = TLS_OPTION_PROTOS;
 	else
 		fprintf(stderr,
-		    "Warning: tsl = off is deprecated and has no effect.\n");
+		    "Warning: tls = off is deprecated and has no effect.\n");
 }
 #line 1672 "cfg_parser.c" /* yacc.c:1646  */
     break;
@@ -1784,7 +1784,7 @@ yyreduce:
 		cfg->SELECTED_TLS_PROTOS = TLS_OPTION_PROTOS;
 	else
 		fprintf(stderr,
-		    "Warning: tsl = off is deprecated and has no effect.\n");
+		    "Warning: tls = off is deprecated and has no effect.\n");
 }
 #line 1790 "cfg_parser.c" /* yacc.c:1646  */
     break;
