@@ -9,15 +9,17 @@
 #define CONFIGURATION_H_INCLUDED
 
 #include <sys/types.h>
-#include <openssl/opensslv.h>
+#include <openssl/ssl.h>
 
 #include "foreign/vqueue.h"
 #include "foreign/uthash.h"
 
 /* Is NPN available? See openssl/opensslv.h for explanation. */
+#ifndef OPENSSL_NO_NEXTPROTONEG
 #if OPENSSL_VERSION_NUMBER >= 0x1000100fL
 #define OPENSSL_WITH_NPN
 #endif
+#endif
 
 /* Is ALPN available? See openssl/opensslv.h for explanation. */
 #if OPENSSL_VERSION_NUMBER >= 0x1000200fL
