@@ -1,7 +1,8 @@
-#/bin/sh
+#!/bin/sh
+#
 # Test basic argument handling.
-# This implements T2 in the original test plan.
-. ${TESTDIR}common.sh
+#
+. ${TESTDIR}/common.sh
 set +o errexit
 
 hitch $HITCH_ARGS --backend=[hitch-tls.org]:80 "--frontend=[${LISTENADDR}]:$LISTENPORT" ${CERTSDIR}/site1.example.com
