@@ -1,11 +1,10 @@
-#/bin/sh
+#!/bin/sh
 #
 # Test multiple listening sockets.
 #
-# This implements T3 in the original test plan.
-. ${TESTDIR}common.sh
+. ${TESTDIR}/common.sh
 
-PORT2=$(($RANDOM + 1024))
+PORT2=`expr $$ % 60000 + 3000`
 
 hitch $HITCH_ARGS --backend=[hitch-tls.org]:80 \
 	"--frontend=[${LISTENADDR}]:$LISTENPORT" \
