@@ -1,12 +1,11 @@
-#/bin/sh
+#!/bin/sh
 #
 # Test multiple listening sockets, each with their own certificate.
 #
-# This implements T3 in the original test plan.
-. ${TESTDIR}common.sh
+. ${TESTDIR}/common.sh
 set +o errexit
 
-PORT2=$(($RANDOM + 1024))
+PORT2=`expr $$ % 60000 + 4000`
 
 hitch $HITCH_ARGS --backend=[hitch-tls.org]:80 \
 	"--frontend=[${LISTENADDR}]:$LISTENPORT+${CERTSDIR}/site1.example.com" \
