@@ -1,12 +1,10 @@
-#/bin/sh
+#!/bin/sh
 #
 # Test --sni-nomatch-abort
 #
-. ${TESTDIR}common.sh
+. ${TESTDIR}/common.sh
 set +o errexit
 
-#PORT2=$(($RANDOM + 1024))
-
 mk_cfg <<EOF
 sni-nomatch-abort = on
 
@@ -23,7 +21,7 @@ frontend = {
 
 frontend = {
 	host = "$LISTENADDR"
-	port = "$((LISTENPORT+1))"
+	port = "`expr $LISTENPORT + 701`"
 	pem-file = "${CERTSDIR}/site3.example.com"
 	sni-nomatch-abort = off
 }
@@ -40,19 +38,21 @@ grep -q -c "subject=/CN=default.example.com" $DUMPFILE
 test "$?" = "0" || die "s_client got wrong certificate on listen port #1"
 
 # SNI request w/ valid servername
-echo -e "\n" | openssl s_client -servername site1.example.com -prexit -connect $LISTENADDR:$LISTENPORT >$DUMPFILE 2>&1
+echo -e "\n" | openssl s_client -servername site1.example.com -prexit \
+	-connect $LISTENADDR:$LISTENPORT >$DUMPFILE 2>&1
 test "$?" = "0" || die "s_client failed"
 grep -q -c "subject=/CN=site1.example.com" $DUMPFILE
 test "$?" = "0" || die "s_client got wrong certificate in listen port #2"
 
 # SNI w/ unknown servername
-echo | openssl s_client -servername invalid.example.com -prexit -connect $LISTENADDR:$LISTENPORT >$DUMPFILE 2>&1
+echo | openssl s_client -servername invalid.example.com -prexit \
+	-connect $LISTENADDR:$LISTENPORT >$DUMPFILE 2>&1
 test "$?" != "0" || die "s_client did NOT fail when it should have. "
 grep -q -c "unrecognized name" $DUMPFILE
 test "$?" = "0" || die "Expected 'unrecognized name' error."
 
 
-HAVE_CURL_RESOLVE=$(curl --help | grep -c -- '--resolve')
+HAVE_CURL_RESOLVE=`curl --help | grep -c -- '--resolve'`
 
 # Disable this part of the test case if the curl version is ancient
 if [ $HAVE_CURL_RESOLVE != "0" ]; then
@@ -61,13 +61,15 @@ if [ $HAVE_CURL_RESOLVE != "0" ]; then
 fi
 
 # SNI request w/ valid servername
-echo -e "\n" | openssl s_client -servername site1.example.com -prexit -connect $LISTENADDR:$((LISTENPORT+1)) >$DUMPFILE 2>&1
+echo -e "\n" | openssl s_client -servername site1.example.com -prexit \
+	-connect $LISTENADDR:`expr $LISTENPORT + 701` >$DUMPFILE 2>&1
 test "$?" = "0" || die "s_client failed"
 grep -q -c "subject=/CN=site3.example.com" $DUMPFILE
 test "$?" = "0" || die "s_client got wrong certificate in listen port #2"
 
 # SNI w/ unknown servername
-echo | openssl s_client -servername invalid.example.com -prexit -connect $LISTENADDR:$((LISTENPORT+1)) >$DUMPFILE 2>&1
+echo | openssl s_client -servername invalid.example.com -prexit \
+	-connect $LISTENADDR:`expr $LISTENPORT + 701` >$DUMPFILE 2>&1
 test "$?" = "0" || die "s_client failed"
 grep -q -c "subject=/CN=site3.example.com" $DUMPFILE
 test "$?" = "0" || die "s_client got wrong certificate in listen port #2"
