@@ -1,12 +1,12 @@
-#/bin/sh
+#!/bin/sh
 # Test configuration parser.
-. ${TESTDIR}common.sh
+. ${TESTDIR}/common.sh
 set +o errexit
 
 # This is a somewhat half-assed attempt at getting a usable group since the
 # redhats and debians can't seem to agree on which group user "nobody"
 # should be in.
-GRP=$(id -Gn nobody | cut -d' ' -f1)
+GRP=`id -Gn nobody | cut -d' ' -f1`
 test "$GRP" != "" || die "No usable group found for user nobody."
 
 hitch --test --config=${CONFDIR}/default.cfg ${CERTSDIR}/default.example.com
@@ -108,3 +108,13 @@ test "$?" = "0" || die "--help after --config does not work as expected."
 # Works as expected.
 hitch --test --config=${CONFDIR}/default.cfg
 test "$?" = "1" || die "--help with --config does not work as expected."
+
+# Test that our example configuration is in fact usable.
+TMPFILE=$(mktemp -u)
+sed -e "s|nogroup|$GRP|" ${TESTDIR}/../../hitch.conf.example > $TMPFILE
+hitch --test --config=$TMPFILE ${CERTSDIR}/default.example.com
+RCODE=$?
+rm $TMPFILE
+if [ "$RCODE" != "0" ]; then
+	die "hitch.conf.example is not valid"
+fi
