@@ -1,13 +1,13 @@
-#/bin/sh
+#!/bin/sh
 
-. ${TESTDIR}common.sh
+. ${TESTDIR}/common.sh
 set +o errexit
 
 mk_cfg <<EOF
 backend = "[hitch-tls.org]:80"
 frontend = {
 	 host = "*"
-	 port = "$((LISTENPORT+2))"
+	 port = "`expr $LISTENPORT + 1200`"
 	 pem-file = "${CERTSDIR}/default.example.com"
 	 tls = on
 	 ciphers = "HIGH"
@@ -18,4 +18,4 @@ EOF
 hitch $HITCH_ARGS --config=$CONFFILE
 test "$?" = "0" || die "Hitch did not start."
 
-runcurl $LISTENADDR $((LISTENPORT+2))
+runcurl $LISTENADDR `expr $LISTENPORT + 1200`
