@@ -1,18 +1,16 @@
-#/bin/sh
+#!/bin/sh
 
-. ${TESTDIR}common.sh
+. ${TESTDIR}/common.sh
 set +o errexit
 unset SSL_CERT_DIR
 unset SSL_CERT_FILE
 
-PORT1=$(($RANDOM + 1024))
-
 mk_cfg <<EOF
 backend = "[hitch-tls.org]:80"
 
 frontend = {
   host = "$LISTENADDR"
-  port = "$PORT1"
+  port = "$LISTENPORT"
 }
 
 pem-file = {
@@ -36,7 +34,7 @@ backend = "[hitch-tls.org]:80"
 
 frontend = {
   host = "$LISTENADDR"
-  port = "$PORT1"
+  port = "$LISTENPORT"
 }
 
 pem-file = {
@@ -48,3 +46,24 @@ EOF
 
 hitch --test $HITCH_ARGS --config=$CONFFILE
 test "$?" = "0" || die "Hitch did not start."
+
+# Test that timeouts are valid configuration file entries. Actually
+# testing the timeouts will be complicated and is deemed unnecessary for now.
+mk_cfg <<EOF
+backend = "[hitch-tls.org]:80"
+
+frontend = {
+  host = "$LISTENADDR"
+  port = "$LISTENPORT"
+}
+
+pem-file = {
+	 cert = "$CERTSDIR/valid.example.com"
+}
+
+ocsp-connect-tmo = 10
+ocsp-resp-tmo = 10
+EOF
+
+hitch --test $HITCH_ARGS --config=$CONFFILE
+test "$?" = "0" || die "Hitch did not start."
