@@ -1,18 +1,21 @@
-#/bin/sh
+#!/bin/sh
 
-. ${TESTDIR}common.sh
+. ${TESTDIR}/common.sh
 set +o errexit
 
-PORT1=$(($RANDOM + 1024))
+BACKENDPORT=`expr $LISTENPORT + 1500`
 
 echo Listen port is $LISTENPORT
 
-hitch $HITCH_ARGS --backend=[127.0.0.1]:$PORT1 "--frontend=[${LISTENADDR}]:$LISTENPORT" ${CERTSDIR}/site1.example.com --write-proxy-v2 --alpn-protos="h2,h2-14,http/1.1"
+hitch $HITCH_ARGS --backend=[127.0.0.1]:$BACKENDPORT "--frontend=[${LISTENADDR}]:$LISTENPORT" \
+	--write-proxy-v2 --alpn-protos="h2,h2-14,http/1.1" \
+	${CERTSDIR}/site1.example.com
 test "$?" = "0" || die "Hitch did not start."
 
-parse_proxy_v2 $PORT1 > $DUMPFILE &
+type parse_proxy_v2 || die "Can't find parse_proxy_v2"
+parse_proxy_v2 $BACKENDPORT > $DUMPFILE &
 
-sleep 1
+sleep 0.1
 
 # If you have nghttp installed, you can try it instead of openssl s_client:
 # nghttp -v "https://localhost:$LISTENPORT"
@@ -20,10 +23,8 @@ sleep 1
 echo -e "\n" | openssl s_client -nextprotoneg 'h2-14' -prexit -connect $LISTENADDR:$LISTENPORT > /dev/null
 test "$?" = "0" || die "s_client failed"
 
-sleep 1
-
 grep -q -c "too old for NPN" $DUMPFILE
-if [ "$" == "0" ]; then
+if [ "$" = "0" ]; then
     echo "Skipping test: SSL too old for NPN"
 else
     grep -q -c "ERROR" $DUMPFILE
