@@ -1,20 +1,24 @@
-#/bin/sh
+#!/bin/sh
 
-. ${TESTDIR}common.sh
+. ${TESTDIR}/common.sh
 set +o errexit
 
-PORT1=$(($RANDOM + 1024))
+BACKENDPORT=`expr $LISTENPORT + 1600`
 
 openssl version > $DUMPFILE
 grep -q -c "OpenSSL 1.0.1" $DUMPFILE
 test "$?" != "0" || skip "OpenSSL does not support ALPN"
 
-hitch $HITCH_ARGS --backend=[127.0.0.1]:$PORT1 "--frontend=[${LISTENADDR}]:$LISTENPORT" ${CERTSDIR}/site1.example.com --write-proxy-v2 --alpn-protos="tor,h2,h2-14,http/1.1"
+hitch $HITCH_ARGS --backend=[127.0.0.1]:$BACKENDPORT "--frontend=[${LISTENADDR}]:$LISTENPORT" \
+	--write-proxy-v2 --alpn-protos="tor,h2,h2-14,http/1.1" \
+	 ${CERTSDIR}/site1.example.com
+
 test "$?" = "0" || die "Hitch did not start."
 
-parse_proxy_v2 $PORT1 > $DUMPFILE &
+type parse_proxy_v2 || die "Unable to find parse_proxy_v2"
+parse_proxy_v2 $BACKENDPORT > $DUMPFILE &
 
-sleep 1
+sleep 0.1
 
 # If you have nghttp installed, you can try it instead of openssl s_client:
 # nghttp -v "https://localhost:$LISTENPORT"
@@ -22,8 +26,6 @@ sleep 1
 echo -e "\n" | openssl s_client -alpn 'h2' -prexit -connect $LISTENADDR:$LISTENPORT > /dev/null
 test "$?" = "0" || die "s_client failed"
 
-sleep 1
-
 grep -q -c "too old for ALPN" $DUMPFILE
 if [ "$" == "0" ]; then
     echo "Skipping test: SSL too old for ALPN"
