@@ -1,6 +1,6 @@
-#/bin/sh
+#!/bin/sh
 
-. ${TESTDIR}common.sh
+. ${TESTDIR}/common.sh
 set +o errexit
 
 
@@ -18,17 +18,16 @@ runcurl $LISTENADDR $LISTENPORT
 # make a faulty config (see test19...sh)
 mk_cfg <<EOF
 pem-file = "${CERTSDIR}/default.example.com"
-frontend = "[$LISTENADDR]:$((LISTENPORT+1))"
+frontend = "[$LISTENADDR]:`expr $LISTENPORT + 1`"
 backend = "[hitch-tls.org]:80"
 tls-protos = SSLv3 TLSv1.0 TLSv1.1 TLSv1.2
 ssl = on
 EOF
 
 kill -HUP $(cat $PIDFILE)
-sleep 1
-curl --max-time 5 --silent --insecure https://$LISTENADDR:$((LISTENPORT+1))/
+sleep 0.5
+curl --max-time 5 --silent --insecure https://$LISTENADDR:`expr $LISTENPORT + 1`/
 test "$?" != "0" || die "New listen endpoint should not be available."
 
-sleep 1
-curl --max-time 5 --silent --insecure https://$LISTENADDR:$((LISTENPORT))/
+curl --max-time 5 --silent --insecure https://$LISTENADDR:$LISTENPORT/
 test "$?" = "0" || die "Old listen endpoint should be available."
